pub struct Facts { /* private fields */ }Implementations
Sourceimpl Facts
impl Facts
Sourcepub fn update_actual_expiration_time(&mut self, expiration_time: u64)
pub fn update_actual_expiration_time(&mut self, expiration_time: u64)
Updates the transaction’s expiration time to the minimum of the current expiration time and the given time. This is used to ensure that the transaction will not be valid after the given time (i.e., after a clawback expires).
Sourcepub fn update_required_expiration_time(&mut self, required_expiration_time: u64)
pub fn update_required_expiration_time(&mut self, required_expiration_time: u64)
Updates the required expiration time to the minimum of the current required expiration time and the given time. This is used to ensure that the transaction will not be valid after the given time (i.e., after a clawback expires).
Sourcepub fn add_reserved_fees(&mut self, amount: u64)
pub fn add_reserved_fees(&mut self, amount: u64)
Adds to the total reserved fees, from coins that have been validated to be linked.
Sourcepub fn assert_puzzle_announcement(&mut self, announcement_id: Bytes32)
pub fn assert_puzzle_announcement(&mut self, announcement_id: Bytes32)
Adds an announcement id to the set of asserted puzzle announcements.
Sourcepub fn assert_spend(&mut self, coin_id: Bytes32)
pub fn assert_spend(&mut self, coin_id: Bytes32)
Adds a coin id to the set of asserted spends.
pub fn actual_expiration_time(&self) -> Option<u64>
pub fn required_expiration_time(&self) -> Option<u64>
pub fn reserved_fees(&self) -> u128
pub fn is_puzzle_announcement_asserted(&self, announcement_id: Bytes32) -> bool
pub fn is_spend_asserted(&self, coin_id: Bytes32) -> bool