P2ControllerPuzzleLayer

Struct P2ControllerPuzzleLayer 

pub struct P2ControllerPuzzleLayer {
    pub controller_puzzle_hash: Bytes32,
}
The CHIP-0037 controller-puzzle Layer.

Locks a coin so it can only be spent when a coin whose puzzle hash equals controller_puzzle_hash sends a RECEIVE_MESSAGE whose body is the tree hash of the chosen delegated_puzzle. Useful for collapsing many per-coin signatures into a single signature on the controller (for example a P2Eip712MessageLayer coin).

Fields

controller_puzzle_hash: Bytes32

Implementations

Source

impl P2ControllerPuzzleLayer

pub fn new(controller_puzzle_hash: Bytes32) -> Self

pub fn spend( &self, ctx: &mut SpendContext, delegated_spend: Spend, ) -> Result<Spend, DriverError>

Spend a coin locked by this layer with a delegated_spend previously authorised by the controller coin.